@@ -1,5 +1,5 @@
 ;;; This file is part of Cedilla.
-;;; Copyright (C) 2002 by Juliusz Chroboczek.
+;;; Copyright (C) 2002-2009 by Juliusz Chroboczek.
 
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -173,6 +173,8 @@
 
 (defun find-magic-glyph (magic ccs font-list &optional font simple)
   "Compute a magic glyph."
+  (when (eq magic ':simplify)
+    (setq simple nil))
   (flet ((f-g (ccs)
            (cond
              ((and font simple) 
@@ -268,7 +270,7 @@
              (and g2 (stack g2 g1)))))
           ;; Vietnamese
           ((and (member c1 '(#x300 #x301)) (eql c2 #x302))
-           (let ((g1 (g ccs1)) (g2 (g ccs2)))
+           (let* ((g1 (g ccs1)) (g2 (and g1 (g ccs2))))
              (when g2
                (let* ((x0-1 (glyph-x0 g1)) (y0-1 (glyph-y0 g1))
                       (x1-1 (glyph-x1 g1))
